pub fn debug_print()Expand description
Prints the current state of the profiler for debugging purposes.
This function prints a debug representation of the entire profiler state to stdout. This is primarily intended for development and debugging use.
Examples
use altius_benchtools::profiler;
// After some profiling...
profiler::debug_print(); // Prints internal profiler state